@@ -20,11 +20,12 @@ class Connection:
     """
     @classmethod
     @asyncio.coroutine
-    def create(cls, host='localhost', port=6379, password=None, db=0, encoder=None, auto_reconnect=True, loop=None):
+    def create(cls, host='localhost', port=6379, password=None, db=0,
+               encoder=None, auto_reconnect=True, loop=None):
         """
-        :param host: Address
+        :param host: Address, either host or unix domain socket path
         :type host: str
-        :param port: TCP port.
+        :param port: TCP port. If port is 0 then host assumed to be unix socket path
         :type port: int
         :param password: Redis database password
         :type password: bytes
@@ -36,16 +37,18 @@ class Connection:
         :type auto_reconnect: bool
         :param loop: (optional) asyncio event loop.
         """
+        assert port >= 0, "Unexpected port value: %r" % (port, )
         connection = cls()
 
         connection.host = host
         connection.port = port
         connection._loop = loop or asyncio.get_event_loop()
         connection._retry_interval = .5
+        connection._closed = False
 
         # Create protocol instance
         def connection_lost():
-            if auto_reconnect:
+            if auto_reconnect and not connection._closed:
                 asyncio.async(connection._reconnect(), loop=connection._loop)
 
         # Create protocol instance
@@ -81,7 +84,10 @@ class Connection:
         while True:
             try:
                 logger.log(logging.INFO, 'Connecting to redis')
-                yield from self._loop.create_connection(lambda:self.protocol, self.host, self.port)
+                if self.port:
+                    yield from self._loop.create_connection(lambda: self.protocol, self.host, self.port)
+                else:
+                    yield from self._loop.create_unix_connection(lambda: self.protocol, self.host)
                 self._reset_retry_interval()
                 return
             except OSError:
@@ -100,3 +106,9 @@ class Connection:
 
     def __repr__(self):
         return 'Connection(host=%r, port=%r)' % (self.host, self.port)
+
+    def __del__(self):
+        """ When this object is cleaned up. Close the transport. """
+        self._closed = True
+        if self.protocol.transport:
+            self.protocol.transport.close()
