@@ -6,6 +6,7 @@ __all__ = (
         'NoRunningScriptError',
         'NotConnectedError',
         'ScriptKilledError',
+        'TimeoutError',
         'TransactionError',
 )
 
@@ -32,6 +33,10 @@ class NotConnectedError(Error):
         super().__init__(message)
 
 
+class TimeoutError(Error):
+    """ Timeout during blocking pop. """
+
+
 class ConnectionLostError(NotConnectedError):
     """
     Connection lost during query.
